@@ -14,23 +14,43 @@ import json
 
 class BertWrapper:
 
-    def __init__(self, lang: Lang, model_name: str = None, max_seq_len: int = 256, check_updates = True):
+    def __init__(self, lang: Lang, model_name: str = None, max_seq_len: int = 256, check_updates = True, custom_model = False, load_model=True):
         self.lang = lang
+        self.custom_model = custom_model
         if lang is Lang.EN:
             if model_name is None:
                 model_name = "bert-base-uncased"
             self.tokenizer = AutoTokenizer.from_pretrained(model_name)
-            self.bert_layer = TFAutoModelWithLMHead.from_pretrained(model_name)
+            if load_model:
+                self.bert_layer = TFAutoModelWithLMHead.from_pretrained(model_name)
         elif lang is Lang.RO:
             if model_name is None:
                 model_name = "base"
-            model_name = f"readerbench/RoBERT-{model_name}"
-            self.tokenizer = AutoTokenizer.from_pretrained(model_name)
-            self.bert_layer = TFAutoModelWithLMHead.from_pretrained(model_name)
+            if self.custom_model:
+                if check_updates and check_version(Lang.RO, ["bert", model_name]):
+                    download_model(Lang.RO, ["bert", model_name])
+                self.model_dir = os.path.join("resources/ro/bert/", model_name)
+                json_config_file = os.path.join(self.model_dir, "bert_config.json")
+                config = json.load(open(json_config_file, 'r'))
+                do_lower_case = bool(config.get('do_lower_case', 0))
+                do_remove_accents = bool(config.get('do_remove_accents', 1))
+                self.hidden_size = config.get('hidden_size')
+                self.tokenizer = FullTokenizer(vocab_file=os.path.join(self.model_dir, "vocab.vocab"), do_lower_case=do_lower_case)
+                if do_remove_accents == False:
+                    self.tokenizer.basic_tokenizer._run_strip_accents = lambda x:x
+                bert_params = bert.params_from_pretrained_ckpt(self.model_dir)
+                if load_model:
+                    self.bert_layer = bert.BertModelLayer.from_params(bert_params, name="bert_layer")
+            else:
+                model_name = f"readerbench/RoBERT-{model_name}"
+                self.tokenizer = AutoTokenizer.from_pretrained(model_name)
+                if load_model:
+                    self.bert_layer = TFAutoModelWithLMHead.from_pretrained(model_name)
         elif lang is Lang.FR:
             self.tokenizer = FlaubertTokenizer.from_pretrained("jplu/tf-flaubert-base-cased")
-            self.bert_layer = TFFlaubertModel.from_pretrained("jplu/tf-flaubert-base-cased")
-            self.bert_layer.call = tf.function(self.bert_layer.call)
+            if load_model:
+                self.bert_layer = TFFlaubertModel.from_pretrained("jplu/tf-flaubert-base-cased")
+                self.bert_layer.call = tf.function(self.bert_layer.call)
 
         
         self.max_seq_len = max_seq_len
@@ -43,6 +63,8 @@ class BertWrapper:
     def create_inputs(self) -> List[keras.layers.Layer]:
         input_ids = tf.keras.layers.Input(shape=(self.max_seq_len,), dtype=tf.int32, name="input_ids")
         segment_ids = tf.keras.layers.Input(shape=(self.max_seq_len,), dtype=tf.int32, name="segment_ids")
+        if self.custom_model:
+            return [input_ids, segment_ids]
         mask_ids = tf.keras.layers.Input(shape=(self.max_seq_len,), dtype=tf.int32, name="mask_ids")
         return [input_ids, mask_ids, segment_ids]
         
@@ -56,7 +78,11 @@ class BertWrapper:
         return inputs, output
 
     def get_output(self, bert_tensor: tf.Tensor, mode: str = "cls") -> tf.Tensor:
-        sequence_output = bert_tensor[0]
+        if self.custom_model:
+            sequence_output = bert_tensor
+        else:
+            sequence_output = bert_tensor[0]
+        
         if mode == "cls":
             return tf.keras.layers.Lambda(lambda x: x[:,0,:])(sequence_output)
         elif mode == "pool":
