@@ -23,6 +23,16 @@ LINKS = {
                 'link': "https://nextcloud.readerbench.com/index.php/s/fd8Ss5NtL6yDoYj/download",
                 'version': "https://nextcloud.readerbench.com/index.php/s/5zJxGKxsLSN4YRd/download"
             },
+            'chains': {
+                'mlp': {
+                    "link": "https://nextcloud.readerbench.com/index.php/s/pWmgazgq5bmkC4e/download",
+                    "version": "https://nextcloud.readerbench.com/index.php/s/Y3tE8587CbN94GJ/download"
+                },
+                'linear': {
+                    "link": "https://nextcloud.readerbench.com/index.php/s/FLCRBYFfSYLAgyT/download",
+                    "version": "https://nextcloud.readerbench.com/index.php/s/8zdybMG7ai5C6ot/download"
+                },
+            },
         },
         'spacy': {},
         'aoa': 'https://nextcloud.readerbench.com/index.php/s/estDka8fYiSNWzj/download',
@@ -50,8 +60,8 @@ LINKS = {
                     "version": "https://nextcloud.readerbench.com/index.php/s/CF5TmPeEKFNib4H/download"
                 },
                 'base': {
-                    "link": "https://nextcloud.readerbench.com/index.php/s/kC98HTJbPmsXxBj/download",
-                    "version": "https://nextcloud.readerbench.com/index.php/s/ix5FRQHEbaP8CFw/download"
+                    "link": "https://nextcloud.readerbench.com/index.php/s/FwWy9TWNHymJ5Hy/download",
+                    "version": "https://nextcloud.readerbench.com/index.php/s/RCp9bgRPF6X3QDq/download"
                 },
                 'large': {
                     "link": "https://nextcloud.readerbench.com/index.php/s/pHXqLQ8HXar44WT/download",
